media

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the media type in the database.
	Label = "media"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// FieldTenantID holds the string denoting the tenant_id field in the database.
	FieldTenantID = "tenant_id"
	// FieldCreatedByID holds the string denoting the created_by_id field in the database.
	FieldCreatedByID = "created_by_id"
	// FieldCreatedAt holds the string denoting the created_at field in the database.
	FieldCreatedAt = "created_at"
	// FieldUpdatedByID holds the string denoting the updated_by_id field in the database.
	FieldUpdatedByID = "updated_by_id"
	// FieldUpdatedAt holds the string denoting the updated_at field in the database.
	FieldUpdatedAt = "updated_at"
	// FieldDeletedByID holds the string denoting the deleted_by_id field in the database.
	FieldDeletedByID = "deleted_by_id"
	// FieldDeletedAt holds the string denoting the deleted_at field in the database.
	FieldDeletedAt = "deleted_at"
	// FieldPublishedAt holds the string denoting the published_at field in the database.
	FieldPublishedAt = "published_at"
	// FieldArchivedAt holds the string denoting the archived_at field in the database.
	FieldArchivedAt = "archived_at"
	// FieldName holds the string denoting the name field in the database.
	FieldName = "name"
	// FieldAlternativeText holds the string denoting the alternative_text field in the database.
	FieldAlternativeText = "alternative_text"
	// FieldCaption holds the string denoting the caption field in the database.
	FieldCaption = "caption"
	// FieldWidth holds the string denoting the width field in the database.
	FieldWidth = "width"
	// FieldHeight holds the string denoting the height field in the database.
	FieldHeight = "height"
	// FieldHash holds the string denoting the hash field in the database.
	FieldHash = "hash"
	// FieldExt holds the string denoting the ext field in the database.
	FieldExt = "ext"
	// FieldMime holds the string denoting the mime field in the database.
	FieldMime = "mime"
	// FieldSize holds the string denoting the size field in the database.
	FieldSize = "size"
	// FieldURL holds the string denoting the url field in the database.
	FieldURL = "url"
	// FieldPreviewURL holds the string denoting the preview_url field in the database.
	FieldPreviewURL = "preview_url"
	// FieldProvider holds the string denoting the provider field in the database.
	FieldProvider = "provider"
	// FieldProviderMetadata holds the string denoting the provider_metadata field in the database.
	FieldProviderMetadata = "provider_metadata"
	// FieldFolderPath holds the string denoting the folder_path field in the database.
	FieldFolderPath = "folder_path"
	// FieldLocale holds the string denoting the locale field in the database.
	FieldLocale = "locale"
	// FieldIsURLSigned holds the string denoting the is_url_signed field in the database.
	FieldIsURLSigned = "is_url_signed"
	// EdgeFormats holds the string denoting the formats edge name in mutations.
	EdgeFormats = "formats"
	// Table holds the table name of the media in the database.
	Table = "media"
	// FormatsTable is the table that holds the formats relation/edge.
	FormatsTable = "media_formats"
	// FormatsInverseTable is the table name for the MediaFormat entity.
	// It exists in this package in order to avoid circular dependency with the "mediaformat" package.
	FormatsInverseTable = "media_formats"
	// FormatsColumn is the table column denoting the formats relation/edge.
	FormatsColumn = "media_id"
)

Variables

var (
	// DefaultTenantID holds the default value on creation for the "tenant_id" field.
	DefaultTenantID string
	// TenantIDValidator is a validator for the "tenant_id" field. It is called by the builders before save.
	TenantIDValidator func(string) error
	// DefaultCreatedAt holds the default value on creation for the "created_at" field.
	DefaultCreatedAt func() time.Time
	// DefaultUpdatedAt holds the default value on creation for the "updated_at" field.
	DefaultUpdatedAt func() time.Time
	// UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field.
	UpdateDefaultUpdatedAt func() time.Time
	// NameValidator is a validator for the "name" field. It is called by the builders before save.
	NameValidator func(string) error
	// URLValidator is a validator for the "url" field. It is called by the builders before save.
	URLValidator func(string) error
	// DefaultID holds the default value on creation for the "id" field.
	DefaultID func() uuid.UUID
)

Columns holds all SQL columns for media fields.

Functions

func AlternativeText

func AlternativeText(v string) predicate.Media

AlternativeText applies equality check predicate on the "alternative_text" field. It's identical to AlternativeTextEQ.

func AlternativeTextContains

func AlternativeTextContains(v string) predicate.Media

AlternativeTextContains applies the Contains predicate on the "alternative_text" field.

func AlternativeTextContainsFold

func AlternativeTextContainsFold(v string) predicate.Media

AlternativeTextContainsFold applies the ContainsFold predicate on the "alternative_text" field.

func AlternativeTextEQ

func AlternativeTextEQ(v string) predicate.Media

AlternativeTextEQ applies the EQ predicate on the "alternative_text" field.

func AlternativeTextEqualFold

func AlternativeTextEqualFold(v string) predicate.Media

AlternativeTextEqualFold applies the EqualFold predicate on the "alternative_text" field.

func AlternativeTextGT

func AlternativeTextGT(v string) predicate.Media

AlternativeTextGT applies the GT predicate on the "alternative_text" field.

func AlternativeTextGTE

func AlternativeTextGTE(v string) predicate.Media

AlternativeTextGTE applies the GTE predicate on the "alternative_text" field.

func AlternativeTextHasPrefix

func AlternativeTextHasPrefix(v string) predicate.Media

AlternativeTextHasPrefix applies the HasPrefix predicate on the "alternative_text" field.

func AlternativeTextHasSuffix

func AlternativeTextHasSuffix(v string) predicate.Media

AlternativeTextHasSuffix applies the HasSuffix predicate on the "alternative_text" field.

func AlternativeTextIn

func AlternativeTextIn(vs ...string) predicate.Media

AlternativeTextIn applies the In predicate on the "alternative_text" field.

func AlternativeTextIsNil

func AlternativeTextIsNil() predicate.Media

AlternativeTextIsNil applies the IsNil predicate on the "alternative_text" field.

func AlternativeTextLT

func AlternativeTextLT(v string) predicate.Media

AlternativeTextLT applies the LT predicate on the "alternative_text" field.

func AlternativeTextLTE

func AlternativeTextLTE(v string) predicate.Media

AlternativeTextLTE applies the LTE predicate on the "alternative_text" field.

func AlternativeTextNEQ

func AlternativeTextNEQ(v string) predicate.Media

AlternativeTextNEQ applies the NEQ predicate on the "alternative_text" field.

func AlternativeTextNotIn

func AlternativeTextNotIn(vs ...string) predicate.Media

AlternativeTextNotIn applies the NotIn predicate on the "alternative_text" field.

func AlternativeTextNotNil

func AlternativeTextNotNil() predicate.Media

AlternativeTextNotNil applies the NotNil predicate on the "alternative_text" field.

func And

func And(predicates ...predicate.Media) predicate.Media

And groups predicates with the AND operator between them.

func ArchivedAt

func ArchivedAt(v time.Time) predicate.Media

ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.

func ArchivedAtEQ

func ArchivedAtEQ(v time.Time) predicate.Media

ArchivedAtEQ applies the EQ predicate on the "archived_at" field.

func ArchivedAtGT

func ArchivedAtGT(v time.Time) predicate.Media

ArchivedAtGT applies the GT predicate on the "archived_at" field.

func ArchivedAtGTE

func ArchivedAtGTE(v time.Time) predicate.Media

ArchivedAtGTE applies the GTE predicate on the "archived_at" field.

func ArchivedAtIn

func ArchivedAtIn(vs ...time.Time) predicate.Media

ArchivedAtIn applies the In predicate on the "archived_at" field.

func ArchivedAtIsNil

func ArchivedAtIsNil() predicate.Media

ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.

func ArchivedAtLT

func ArchivedAtLT(v time.Time) predicate.Media

ArchivedAtLT applies the LT predicate on the "archived_at" field.

func ArchivedAtLTE

func ArchivedAtLTE(v time.Time) predicate.Media

ArchivedAtLTE applies the LTE predicate on the "archived_at" field.

func ArchivedAtNEQ

func ArchivedAtNEQ(v time.Time) predicate.Media

ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.

func ArchivedAtNotIn

func ArchivedAtNotIn(vs ...time.Time) predicate.Media

ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.

func ArchivedAtNotNil

func ArchivedAtNotNil() predicate.Media

ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.

func Caption

func Caption(v string) predicate.Media

Caption applies equality check predicate on the "caption" field. It's identical to CaptionEQ.

func CaptionContains

func CaptionContains(v string) predicate.Media

CaptionContains applies the Contains predicate on the "caption" field.

func CaptionContainsFold

func CaptionContainsFold(v string) predicate.Media

CaptionContainsFold applies the ContainsFold predicate on the "caption" field.

func CaptionEQ

func CaptionEQ(v string) predicate.Media

CaptionEQ applies the EQ predicate on the "caption" field.

func CaptionEqualFold

func CaptionEqualFold(v string) predicate.Media

CaptionEqualFold applies the EqualFold predicate on the "caption" field.

func CaptionGT

func CaptionGT(v string) predicate.Media

CaptionGT applies the GT predicate on the "caption" field.

func CaptionGTE

func CaptionGTE(v string) predicate.Media

CaptionGTE applies the GTE predicate on the "caption" field.

func CaptionHasPrefix

func CaptionHasPrefix(v string) predicate.Media

CaptionHasPrefix applies the HasPrefix predicate on the "caption" field.

func CaptionHasSuffix

func CaptionHasSuffix(v string) predicate.Media

CaptionHasSuffix applies the HasSuffix predicate on the "caption" field.

func CaptionIn

func CaptionIn(vs ...string) predicate.Media

CaptionIn applies the In predicate on the "caption" field.

func CaptionIsNil

func CaptionIsNil() predicate.Media

CaptionIsNil applies the IsNil predicate on the "caption" field.

func CaptionLT

func CaptionLT(v string) predicate.Media

CaptionLT applies the LT predicate on the "caption" field.

func CaptionLTE

func CaptionLTE(v string) predicate.Media

CaptionLTE applies the LTE predicate on the "caption" field.

func CaptionNEQ

func CaptionNEQ(v string) predicate.Media

CaptionNEQ applies the NEQ predicate on the "caption" field.

func CaptionNotIn

func CaptionNotIn(vs ...string) predicate.Media

CaptionNotIn applies the NotIn predicate on the "caption" field.

func CaptionNotNil

func CaptionNotNil() predicate.Media

CaptionNotNil applies the NotNil predicate on the "caption" field.

func CreatedAt

func CreatedAt(v time.Time) predicate.Media

CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.

func CreatedAtEQ

func CreatedAtEQ(v time.Time) predicate.Media

CreatedAtEQ applies the EQ predicate on the "created_at" field.

func CreatedAtGT

func CreatedAtGT(v time.Time) predicate.Media

CreatedAtGT applies the GT predicate on the "created_at" field.

func CreatedAtGTE

func CreatedAtGTE(v time.Time) predicate.Media

CreatedAtGTE applies the GTE predicate on the "created_at" field.

func CreatedAtIn

func CreatedAtIn(vs ...time.Time) predicate.Media

CreatedAtIn applies the In predicate on the "created_at" field.

func CreatedAtIsNil

func CreatedAtIsNil() predicate.Media

CreatedAtIsNil applies the IsNil predicate on the "created_at" field.

func CreatedAtLT

func CreatedAtLT(v time.Time) predicate.Media

CreatedAtLT applies the LT predicate on the "created_at" field.

func CreatedAtLTE

func CreatedAtLTE(v time.Time) predicate.Media

CreatedAtLTE applies the LTE predicate on the "created_at" field.

func CreatedAtNEQ

func CreatedAtNEQ(v time.Time) predicate.Media

CreatedAtNEQ applies the NEQ predicate on the "created_at" field.

func CreatedAtNotIn

func CreatedAtNotIn(vs ...time.Time) predicate.Media

CreatedAtNotIn applies the NotIn predicate on the "created_at" field.

func CreatedAtNotNil

func CreatedAtNotNil() predicate.Media

CreatedAtNotNil applies the NotNil predicate on the "created_at" field.

func CreatedByID

func CreatedByID(v uuid.UUID) predicate.Media

CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.

func CreatedByIDEQ

func CreatedByIDEQ(v uuid.UUID) predicate.Media

CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.

func CreatedByIDGT

func CreatedByIDGT(v uuid.UUID) predicate.Media

CreatedByIDGT applies the GT predicate on the "created_by_id" field.

func CreatedByIDGTE

func CreatedByIDGTE(v uuid.UUID) predicate.Media

CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.

func CreatedByIDIn

func CreatedByIDIn(vs ...uuid.UUID) predicate.Media

CreatedByIDIn applies the In predicate on the "created_by_id" field.

func CreatedByIDIsNil

func CreatedByIDIsNil() predicate.Media

CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.

func CreatedByIDLT

func CreatedByIDLT(v uuid.UUID) predicate.Media

CreatedByIDLT applies the LT predicate on the "created_by_id" field.

func CreatedByIDLTE

func CreatedByIDLTE(v uuid.UUID) predicate.Media

CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.

func CreatedByIDNEQ

func CreatedByIDNEQ(v uuid.UUID) predicate.Media

CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.

func CreatedByIDNotIn

func CreatedByIDNotIn(vs ...uuid.UUID) predicate.Media

CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.

func CreatedByIDNotNil

func CreatedByIDNotNil() predicate.Media

CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.

func DeletedAt

func DeletedAt(v time.Time) predicate.Media

DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.

func DeletedAtEQ

func DeletedAtEQ(v time.Time) predicate.Media

DeletedAtEQ applies the EQ predicate on the "deleted_at" field.

func DeletedAtGT

func DeletedAtGT(v time.Time) predicate.Media

DeletedAtGT applies the GT predicate on the "deleted_at" field.

func DeletedAtGTE

func DeletedAtGTE(v time.Time) predicate.Media

DeletedAtGTE applies the GTE predicate on the "deleted_at" field.

func DeletedAtIn

func DeletedAtIn(vs ...time.Time) predicate.Media

DeletedAtIn applies the In predicate on the "deleted_at" field.

func DeletedAtIsNil

func DeletedAtIsNil() predicate.Media

DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.

func DeletedAtLT

func DeletedAtLT(v time.Time) predicate.Media

DeletedAtLT applies the LT predicate on the "deleted_at" field.

func DeletedAtLTE

func DeletedAtLTE(v time.Time) predicate.Media

DeletedAtLTE applies the LTE predicate on the "deleted_at" field.

func DeletedAtNEQ

func DeletedAtNEQ(v time.Time) predicate.Media

DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.

func DeletedAtNotIn

func DeletedAtNotIn(vs ...time.Time) predicate.Media

DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.

func DeletedAtNotNil

func DeletedAtNotNil() predicate.Media

DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.

func DeletedByID

func DeletedByID(v uuid.UUID) predicate.Media

DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.

func DeletedByIDEQ

func DeletedByIDEQ(v uuid.UUID) predicate.Media

DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.

func DeletedByIDGT

func DeletedByIDGT(v uuid.UUID) predicate.Media

DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.

func DeletedByIDGTE

func DeletedByIDGTE(v uuid.UUID) predicate.Media

DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.

func DeletedByIDIn

func DeletedByIDIn(vs ...uuid.UUID) predicate.Media

DeletedByIDIn applies the In predicate on the "deleted_by_id" field.

func DeletedByIDIsNil

func DeletedByIDIsNil() predicate.Media

DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.

func DeletedByIDLT

func DeletedByIDLT(v uuid.UUID) predicate.Media

DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.

func DeletedByIDLTE

func DeletedByIDLTE(v uuid.UUID) predicate.Media

DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.

func DeletedByIDNEQ

func DeletedByIDNEQ(v uuid.UUID) predicate.Media

DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.

func DeletedByIDNotIn

func DeletedByIDNotIn(vs ...uuid.UUID) predicate.Media

DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.

func DeletedByIDNotNil

func DeletedByIDNotNil() predicate.Media

DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.

func Ext

func Ext(v string) predicate.Media

Ext applies equality check predicate on the "ext" field. It's identical to ExtEQ.

func ExtContains

func ExtContains(v string) predicate.Media

ExtContains applies the Contains predicate on the "ext" field.

func ExtContainsFold

func ExtContainsFold(v string) predicate.Media

ExtContainsFold applies the ContainsFold predicate on the "ext" field.

func ExtEQ

func ExtEQ(v string) predicate.Media

ExtEQ applies the EQ predicate on the "ext" field.

func ExtEqualFold

func ExtEqualFold(v string) predicate.Media

ExtEqualFold applies the EqualFold predicate on the "ext" field.

func ExtGT

func ExtGT(v string) predicate.Media

ExtGT applies the GT predicate on the "ext" field.

func ExtGTE

func ExtGTE(v string) predicate.Media

ExtGTE applies the GTE predicate on the "ext" field.

func ExtHasPrefix

func ExtHasPrefix(v string) predicate.Media

ExtHasPrefix applies the HasPrefix predicate on the "ext" field.

func ExtHasSuffix

func ExtHasSuffix(v string) predicate.Media

ExtHasSuffix applies the HasSuffix predicate on the "ext" field.

func ExtIn

func ExtIn(vs ...string) predicate.Media

ExtIn applies the In predicate on the "ext" field.

func ExtIsNil

func ExtIsNil() predicate.Media

ExtIsNil applies the IsNil predicate on the "ext" field.

func ExtLT

func ExtLT(v string) predicate.Media

ExtLT applies the LT predicate on the "ext" field.

func ExtLTE

func ExtLTE(v string) predicate.Media

ExtLTE applies the LTE predicate on the "ext" field.

func ExtNEQ

func ExtNEQ(v string) predicate.Media

ExtNEQ applies the NEQ predicate on the "ext" field.

func ExtNotIn

func ExtNotIn(vs ...string) predicate.Media

ExtNotIn applies the NotIn predicate on the "ext" field.

func ExtNotNil

func ExtNotNil() predicate.Media

ExtNotNil applies the NotNil predicate on the "ext" field.

func FolderPath

func FolderPath(v string) predicate.Media

FolderPath applies equality check predicate on the "folder_path" field. It's identical to FolderPathEQ.

func FolderPathContains

func FolderPathContains(v string) predicate.Media

FolderPathContains applies the Contains predicate on the "folder_path" field.

func FolderPathContainsFold

func FolderPathContainsFold(v string) predicate.Media

FolderPathContainsFold applies the ContainsFold predicate on the "folder_path" field.

func FolderPathEQ

func FolderPathEQ(v string) predicate.Media

FolderPathEQ applies the EQ predicate on the "folder_path" field.

func FolderPathEqualFold

func FolderPathEqualFold(v string) predicate.Media

FolderPathEqualFold applies the EqualFold predicate on the "folder_path" field.

func FolderPathGT

func FolderPathGT(v string) predicate.Media

FolderPathGT applies the GT predicate on the "folder_path" field.

func FolderPathGTE

func FolderPathGTE(v string) predicate.Media

FolderPathGTE applies the GTE predicate on the "folder_path" field.

func FolderPathHasPrefix

func FolderPathHasPrefix(v string) predicate.Media

FolderPathHasPrefix applies the HasPrefix predicate on the "folder_path" field.

func FolderPathHasSuffix

func FolderPathHasSuffix(v string) predicate.Media

FolderPathHasSuffix applies the HasSuffix predicate on the "folder_path" field.

func FolderPathIn

func FolderPathIn(vs ...string) predicate.Media

FolderPathIn applies the In predicate on the "folder_path" field.

func FolderPathIsNil

func FolderPathIsNil() predicate.Media

FolderPathIsNil applies the IsNil predicate on the "folder_path" field.

func FolderPathLT

func FolderPathLT(v string) predicate.Media

FolderPathLT applies the LT predicate on the "folder_path" field.

func FolderPathLTE

func FolderPathLTE(v string) predicate.Media

FolderPathLTE applies the LTE predicate on the "folder_path" field.

func FolderPathNEQ

func FolderPathNEQ(v string) predicate.Media

FolderPathNEQ applies the NEQ predicate on the "folder_path" field.

func FolderPathNotIn

func FolderPathNotIn(vs ...string) predicate.Media

FolderPathNotIn applies the NotIn predicate on the "folder_path" field.

func FolderPathNotNil

func FolderPathNotNil() predicate.Media

FolderPathNotNil applies the NotNil predicate on the "folder_path" field.

func HasFormats

func HasFormats() predicate.Media

HasFormats applies the HasEdge predicate on the "formats" edge.

func HasFormatsWith

func HasFormatsWith(preds ...predicate.MediaFormat) predicate.Media

HasFormatsWith applies the HasEdge predicate on the "formats" edge with a given conditions (other predicates).

func Hash

func Hash(v string) predicate.Media

Hash applies equality check predicate on the "hash" field. It's identical to HashEQ.

func HashContains

func HashContains(v string) predicate.Media

HashContains applies the Contains predicate on the "hash" field.

func HashContainsFold

func HashContainsFold(v string) predicate.Media

HashContainsFold applies the ContainsFold predicate on the "hash" field.

func HashEQ

func HashEQ(v string) predicate.Media

HashEQ applies the EQ predicate on the "hash" field.

func HashEqualFold

func HashEqualFold(v string) predicate.Media

HashEqualFold applies the EqualFold predicate on the "hash" field.

func HashGT

func HashGT(v string) predicate.Media

HashGT applies the GT predicate on the "hash" field.

func HashGTE

func HashGTE(v string) predicate.Media

HashGTE applies the GTE predicate on the "hash" field.

func HashHasPrefix

func HashHasPrefix(v string) predicate.Media

HashHasPrefix applies the HasPrefix predicate on the "hash" field.

func HashHasSuffix

func HashHasSuffix(v string) predicate.Media

HashHasSuffix applies the HasSuffix predicate on the "hash" field.

func HashIn

func HashIn(vs ...string) predicate.Media

HashIn applies the In predicate on the "hash" field.

func HashIsNil

func HashIsNil() predicate.Media

HashIsNil applies the IsNil predicate on the "hash" field.

func HashLT

func HashLT(v string) predicate.Media

HashLT applies the LT predicate on the "hash" field.

func HashLTE

func HashLTE(v string) predicate.Media

HashLTE applies the LTE predicate on the "hash" field.

func HashNEQ

func HashNEQ(v string) predicate.Media

HashNEQ applies the NEQ predicate on the "hash" field.

func HashNotIn

func HashNotIn(vs ...string) predicate.Media

HashNotIn applies the NotIn predicate on the "hash" field.

func HashNotNil

func HashNotNil() predicate.Media

HashNotNil applies the NotNil predicate on the "hash" field.

func Height

func Height(v int) predicate.Media

Height applies equality check predicate on the "height" field. It's identical to HeightEQ.

func HeightEQ

func HeightEQ(v int) predicate.Media

HeightEQ applies the EQ predicate on the "height" field.

func HeightGT

func HeightGT(v int) predicate.Media

HeightGT applies the GT predicate on the "height" field.

func HeightGTE

func HeightGTE(v int) predicate.Media

HeightGTE applies the GTE predicate on the "height" field.

func HeightIn

func HeightIn(vs ...int) predicate.Media

HeightIn applies the In predicate on the "height" field.

func HeightIsNil

func HeightIsNil() predicate.Media

HeightIsNil applies the IsNil predicate on the "height" field.

func HeightLT

func HeightLT(v int) predicate.Media

HeightLT applies the LT predicate on the "height" field.

func HeightLTE

func HeightLTE(v int) predicate.Media

HeightLTE applies the LTE predicate on the "height" field.

func HeightNEQ

func HeightNEQ(v int) predicate.Media

HeightNEQ applies the NEQ predicate on the "height" field.

func HeightNotIn

func HeightNotIn(vs ...int) predicate.Media

HeightNotIn applies the NotIn predicate on the "height" field.

func HeightNotNil

func HeightNotNil() predicate.Media

HeightNotNil applies the NotNil predicate on the "height" field.

func ID

func ID(id uuid.UUID) predicate.Media

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id uuid.UUID) predicate.Media

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id uuid.UUID) predicate.Media

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id uuid.UUID) predicate.Media

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...uuid.UUID) predicate.Media

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id uuid.UUID) predicate.Media

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id uuid.UUID) predicate.Media

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id uuid.UUID) predicate.Media

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...uuid.UUID) predicate.Media

IDNotIn applies the NotIn predicate on the ID field.

func IsURLSigned

func IsURLSigned(v bool) predicate.Media

IsURLSigned applies equality check predicate on the "is_url_signed" field. It's identical to IsURLSignedEQ.

func IsURLSignedEQ

func IsURLSignedEQ(v bool) predicate.Media

IsURLSignedEQ applies the EQ predicate on the "is_url_signed" field.

func IsURLSignedIsNil

func IsURLSignedIsNil() predicate.Media

IsURLSignedIsNil applies the IsNil predicate on the "is_url_signed" field.

func IsURLSignedNEQ

func IsURLSignedNEQ(v bool) predicate.Media

IsURLSignedNEQ applies the NEQ predicate on the "is_url_signed" field.

func IsURLSignedNotNil

func IsURLSignedNotNil() predicate.Media

IsURLSignedNotNil applies the NotNil predicate on the "is_url_signed" field.

func Locale

func Locale(v string) predicate.Media

Locale applies equality check predicate on the "locale" field. It's identical to LocaleEQ.

func LocaleContains

func LocaleContains(v string) predicate.Media

LocaleContains applies the Contains predicate on the "locale" field.

func LocaleContainsFold

func LocaleContainsFold(v string) predicate.Media

LocaleContainsFold applies the ContainsFold predicate on the "locale" field.

func LocaleEQ

func LocaleEQ(v string) predicate.Media

LocaleEQ applies the EQ predicate on the "locale" field.

func LocaleEqualFold

func LocaleEqualFold(v string) predicate.Media

LocaleEqualFold applies the EqualFold predicate on the "locale" field.

func LocaleGT

func LocaleGT(v string) predicate.Media

LocaleGT applies the GT predicate on the "locale" field.

func LocaleGTE

func LocaleGTE(v string) predicate.Media

LocaleGTE applies the GTE predicate on the "locale" field.

func LocaleHasPrefix

func LocaleHasPrefix(v string) predicate.Media

LocaleHasPrefix applies the HasPrefix predicate on the "locale" field.

func LocaleHasSuffix

func LocaleHasSuffix(v string) predicate.Media

LocaleHasSuffix applies the HasSuffix predicate on the "locale" field.

func LocaleIn

func LocaleIn(vs ...string) predicate.Media

LocaleIn applies the In predicate on the "locale" field.

func LocaleIsNil

func LocaleIsNil() predicate.Media

LocaleIsNil applies the IsNil predicate on the "locale" field.

func LocaleLT

func LocaleLT(v string) predicate.Media

LocaleLT applies the LT predicate on the "locale" field.

func LocaleLTE

func LocaleLTE(v string) predicate.Media

LocaleLTE applies the LTE predicate on the "locale" field.

func LocaleNEQ

func LocaleNEQ(v string) predicate.Media

LocaleNEQ applies the NEQ predicate on the "locale" field.

func LocaleNotIn

func LocaleNotIn(vs ...string) predicate.Media

LocaleNotIn applies the NotIn predicate on the "locale" field.

func LocaleNotNil

func LocaleNotNil() predicate.Media

LocaleNotNil applies the NotNil predicate on the "locale" field.

func Mime

func Mime(v string) predicate.Media

Mime applies equality check predicate on the "mime" field. It's identical to MimeEQ.

func MimeContains

func MimeContains(v string) predicate.Media

MimeContains applies the Contains predicate on the "mime" field.

func MimeContainsFold

func MimeContainsFold(v string) predicate.Media

MimeContainsFold applies the ContainsFold predicate on the "mime" field.

func MimeEQ

func MimeEQ(v string) predicate.Media

MimeEQ applies the EQ predicate on the "mime" field.

func MimeEqualFold

func MimeEqualFold(v string) predicate.Media

MimeEqualFold applies the EqualFold predicate on the "mime" field.

func MimeGT

func MimeGT(v string) predicate.Media

MimeGT applies the GT predicate on the "mime" field.

func MimeGTE

func MimeGTE(v string) predicate.Media

MimeGTE applies the GTE predicate on the "mime" field.

func MimeHasPrefix

func MimeHasPrefix(v string) predicate.Media

MimeHasPrefix applies the HasPrefix predicate on the "mime" field.

func MimeHasSuffix

func MimeHasSuffix(v string) predicate.Media

MimeHasSuffix applies the HasSuffix predicate on the "mime" field.

func MimeIn

func MimeIn(vs ...string) predicate.Media

MimeIn applies the In predicate on the "mime" field.

func MimeIsNil

func MimeIsNil() predicate.Media

MimeIsNil applies the IsNil predicate on the "mime" field.

func MimeLT

func MimeLT(v string) predicate.Media

MimeLT applies the LT predicate on the "mime" field.

func MimeLTE

func MimeLTE(v string) predicate.Media

MimeLTE applies the LTE predicate on the "mime" field.

func MimeNEQ

func MimeNEQ(v string) predicate.Media

MimeNEQ applies the NEQ predicate on the "mime" field.

func MimeNotIn

func MimeNotIn(vs ...string) predicate.Media

MimeNotIn applies the NotIn predicate on the "mime" field.

func MimeNotNil

func MimeNotNil() predicate.Media

MimeNotNil applies the NotNil predicate on the "mime" field.

func Name

func Name(v string) predicate.Media

Name applies equality check predicate on the "name" field. It's identical to NameEQ.

func NameContains

func NameContains(v string) predicate.Media

NameContains applies the Contains predicate on the "name" field.

func NameContainsFold

func NameContainsFold(v string) predicate.Media

NameContainsFold applies the ContainsFold predicate on the "name" field.

func NameEQ

func NameEQ(v string) predicate.Media

NameEQ applies the EQ predicate on the "name" field.

func NameEqualFold

func NameEqualFold(v string) predicate.Media

NameEqualFold applies the EqualFold predicate on the "name" field.

func NameGT

func NameGT(v string) predicate.Media

NameGT applies the GT predicate on the "name" field.

func NameGTE

func NameGTE(v string) predicate.Media

NameGTE applies the GTE predicate on the "name" field.

func NameHasPrefix

func NameHasPrefix(v string) predicate.Media

NameHasPrefix applies the HasPrefix predicate on the "name" field.

func NameHasSuffix

func NameHasSuffix(v string) predicate.Media

NameHasSuffix applies the HasSuffix predicate on the "name" field.

func NameIn

func NameIn(vs ...string) predicate.Media

NameIn applies the In predicate on the "name" field.

func NameLT

func NameLT(v string) predicate.Media

NameLT applies the LT predicate on the "name" field.

func NameLTE

func NameLTE(v string) predicate.Media

NameLTE applies the LTE predicate on the "name" field.

func NameNEQ

func NameNEQ(v string) predicate.Media

NameNEQ applies the NEQ predicate on the "name" field.

func NameNotIn

func NameNotIn(vs ...string) predicate.Media

NameNotIn applies the NotIn predicate on the "name" field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Media) predicate.Media

Or groups predicates with the OR operator between them.

func PreviewURL

func PreviewURL(v string) predicate.Media

PreviewURL applies equality check predicate on the "preview_url" field. It's identical to PreviewURLEQ.

func PreviewURLContains

func PreviewURLContains(v string) predicate.Media

PreviewURLContains applies the Contains predicate on the "preview_url" field.

func PreviewURLContainsFold

func PreviewURLContainsFold(v string) predicate.Media

PreviewURLContainsFold applies the ContainsFold predicate on the "preview_url" field.

func PreviewURLEQ

func PreviewURLEQ(v string) predicate.Media

PreviewURLEQ applies the EQ predicate on the "preview_url" field.

func PreviewURLEqualFold

func PreviewURLEqualFold(v string) predicate.Media

PreviewURLEqualFold applies the EqualFold predicate on the "preview_url" field.

func PreviewURLGT

func PreviewURLGT(v string) predicate.Media

PreviewURLGT applies the GT predicate on the "preview_url" field.

func PreviewURLGTE

func PreviewURLGTE(v string) predicate.Media

PreviewURLGTE applies the GTE predicate on the "preview_url" field.

func PreviewURLHasPrefix

func PreviewURLHasPrefix(v string) predicate.Media

PreviewURLHasPrefix applies the HasPrefix predicate on the "preview_url" field.

func PreviewURLHasSuffix

func PreviewURLHasSuffix(v string) predicate.Media

PreviewURLHasSuffix applies the HasSuffix predicate on the "preview_url" field.

func PreviewURLIn

func PreviewURLIn(vs ...string) predicate.Media

PreviewURLIn applies the In predicate on the "preview_url" field.

func PreviewURLIsNil

func PreviewURLIsNil() predicate.Media

PreviewURLIsNil applies the IsNil predicate on the "preview_url" field.

func PreviewURLLT

func PreviewURLLT(v string) predicate.Media

PreviewURLLT applies the LT predicate on the "preview_url" field.

func PreviewURLLTE

func PreviewURLLTE(v string) predicate.Media

PreviewURLLTE applies the LTE predicate on the "preview_url" field.

func PreviewURLNEQ

func PreviewURLNEQ(v string) predicate.Media

PreviewURLNEQ applies the NEQ predicate on the "preview_url" field.

func PreviewURLNotIn

func PreviewURLNotIn(vs ...string) predicate.Media

PreviewURLNotIn applies the NotIn predicate on the "preview_url" field.

func PreviewURLNotNil

func PreviewURLNotNil() predicate.Media

PreviewURLNotNil applies the NotNil predicate on the "preview_url" field.

func Provider

func Provider(v string) predicate.Media

Provider applies equality check predicate on the "provider" field. It's identical to ProviderEQ.

func ProviderContains

func ProviderContains(v string) predicate.Media

ProviderContains applies the Contains predicate on the "provider" field.

func ProviderContainsFold

func ProviderContainsFold(v string) predicate.Media

ProviderContainsFold applies the ContainsFold predicate on the "provider" field.

func ProviderEQ

func ProviderEQ(v string) predicate.Media

ProviderEQ applies the EQ predicate on the "provider" field.

func ProviderEqualFold

func ProviderEqualFold(v string) predicate.Media

ProviderEqualFold applies the EqualFold predicate on the "provider" field.

func ProviderGT

func ProviderGT(v string) predicate.Media

ProviderGT applies the GT predicate on the "provider" field.

func ProviderGTE

func ProviderGTE(v string) predicate.Media

ProviderGTE applies the GTE predicate on the "provider" field.

func ProviderHasPrefix

func ProviderHasPrefix(v string) predicate.Media

ProviderHasPrefix applies the HasPrefix predicate on the "provider" field.

func ProviderHasSuffix

func ProviderHasSuffix(v string) predicate.Media

ProviderHasSuffix applies the HasSuffix predicate on the "provider" field.

func ProviderIn

func ProviderIn(vs ...string) predicate.Media

ProviderIn applies the In predicate on the "provider" field.

func ProviderIsNil

func ProviderIsNil() predicate.Media

ProviderIsNil applies the IsNil predicate on the "provider" field.

func ProviderLT

func ProviderLT(v string) predicate.Media

ProviderLT applies the LT predicate on the "provider" field.

func ProviderLTE

func ProviderLTE(v string) predicate.Media

ProviderLTE applies the LTE predicate on the "provider" field.

func ProviderMetadataIsNil

func ProviderMetadataIsNil() predicate.Media

ProviderMetadataIsNil applies the IsNil predicate on the "provider_metadata" field.

func ProviderMetadataNotNil

func ProviderMetadataNotNil() predicate.Media

ProviderMetadataNotNil applies the NotNil predicate on the "provider_metadata" field.

func ProviderNEQ

func ProviderNEQ(v string) predicate.Media

ProviderNEQ applies the NEQ predicate on the "provider" field.

func ProviderNotIn

func ProviderNotIn(vs ...string) predicate.Media

ProviderNotIn applies the NotIn predicate on the "provider" field.

func ProviderNotNil

func ProviderNotNil() predicate.Media

ProviderNotNil applies the NotNil predicate on the "provider" field.

func PublishedAt

func PublishedAt(v time.Time) predicate.Media

PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.

func PublishedAtEQ

func PublishedAtEQ(v time.Time) predicate.Media

PublishedAtEQ applies the EQ predicate on the "published_at" field.

func PublishedAtGT

func PublishedAtGT(v time.Time) predicate.Media

PublishedAtGT applies the GT predicate on the "published_at" field.

func PublishedAtGTE

func PublishedAtGTE(v time.Time) predicate.Media

PublishedAtGTE applies the GTE predicate on the "published_at" field.

func PublishedAtIn

func PublishedAtIn(vs ...time.Time) predicate.Media

PublishedAtIn applies the In predicate on the "published_at" field.

func PublishedAtIsNil

func PublishedAtIsNil() predicate.Media

PublishedAtIsNil applies the IsNil predicate on the "published_at" field.

func PublishedAtLT

func PublishedAtLT(v time.Time) predicate.Media

PublishedAtLT applies the LT predicate on the "published_at" field.

func PublishedAtLTE

func PublishedAtLTE(v time.Time) predicate.Media

PublishedAtLTE applies the LTE predicate on the "published_at" field.

func PublishedAtNEQ

func PublishedAtNEQ(v time.Time) predicate.Media

PublishedAtNEQ applies the NEQ predicate on the "published_at" field.

func PublishedAtNotIn

func PublishedAtNotIn(vs ...time.Time) predicate.Media

PublishedAtNotIn applies the NotIn predicate on the "published_at" field.

func PublishedAtNotNil

func PublishedAtNotNil() predicate.Media

PublishedAtNotNil applies the NotNil predicate on the "published_at" field.

func Size

func Size(v float64) predicate.Media

Size applies equality check predicate on the "size" field. It's identical to SizeEQ.

func SizeEQ

func SizeEQ(v float64) predicate.Media

SizeEQ applies the EQ predicate on the "size" field.

func SizeGT

func SizeGT(v float64) predicate.Media

SizeGT applies the GT predicate on the "size" field.

func SizeGTE

func SizeGTE(v float64) predicate.Media

SizeGTE applies the GTE predicate on the "size" field.

func SizeIn

func SizeIn(vs ...float64) predicate.Media

SizeIn applies the In predicate on the "size" field.

func SizeIsNil

func SizeIsNil() predicate.Media

SizeIsNil applies the IsNil predicate on the "size" field.

func SizeLT

func SizeLT(v float64) predicate.Media

SizeLT applies the LT predicate on the "size" field.

func SizeLTE

func SizeLTE(v float64) predicate.Media

SizeLTE applies the LTE predicate on the "size" field.

func SizeNEQ

func SizeNEQ(v float64) predicate.Media

SizeNEQ applies the NEQ predicate on the "size" field.

func SizeNotIn

func SizeNotIn(vs ...float64) predicate.Media

SizeNotIn applies the NotIn predicate on the "size" field.

func SizeNotNil

func SizeNotNil() predicate.Media

SizeNotNil applies the NotNil predicate on the "size" field.

func TenantID

func TenantID(v string) predicate.Media

TenantID applies equality check predicate on the "tenant_id" field. It's identical to TenantIDEQ.

func TenantIDContains

func TenantIDContains(v string) predicate.Media

TenantIDContains applies the Contains predicate on the "tenant_id" field.

func TenantIDContainsFold

func TenantIDContainsFold(v string) predicate.Media

TenantIDContainsFold applies the ContainsFold predicate on the "tenant_id" field.

func TenantIDEQ

func TenantIDEQ(v string) predicate.Media

TenantIDEQ applies the EQ predicate on the "tenant_id" field.

func TenantIDEqualFold

func TenantIDEqualFold(v string) predicate.Media

TenantIDEqualFold applies the EqualFold predicate on the "tenant_id" field.

func TenantIDGT

func TenantIDGT(v string) predicate.Media

TenantIDGT applies the GT predicate on the "tenant_id" field.

func TenantIDGTE

func TenantIDGTE(v string) predicate.Media

TenantIDGTE applies the GTE predicate on the "tenant_id" field.

func TenantIDHasPrefix

func TenantIDHasPrefix(v string) predicate.Media

TenantIDHasPrefix applies the HasPrefix predicate on the "tenant_id" field.

func TenantIDHasSuffix

func TenantIDHasSuffix(v string) predicate.Media

TenantIDHasSuffix applies the HasSuffix predicate on the "tenant_id" field.

func TenantIDIn

func TenantIDIn(vs ...string) predicate.Media

TenantIDIn applies the In predicate on the "tenant_id" field.

func TenantIDLT

func TenantIDLT(v string) predicate.Media

TenantIDLT applies the LT predicate on the "tenant_id" field.

func TenantIDLTE

func TenantIDLTE(v string) predicate.Media

TenantIDLTE applies the LTE predicate on the "tenant_id" field.

func TenantIDNEQ

func TenantIDNEQ(v string) predicate.Media

TenantIDNEQ applies the NEQ predicate on the "tenant_id" field.

func TenantIDNotIn

func TenantIDNotIn(vs ...string) predicate.Media

TenantIDNotIn applies the NotIn predicate on the "tenant_id" field.

func URL

func URL(v string) predicate.Media

URL applies equality check predicate on the "url" field. It's identical to URLEQ.

func URLContains

func URLContains(v string) predicate.Media

URLContains applies the Contains predicate on the "url" field.

func URLContainsFold

func URLContainsFold(v string) predicate.Media

URLContainsFold applies the ContainsFold predicate on the "url" field.

func URLEQ

func URLEQ(v string) predicate.Media

URLEQ applies the EQ predicate on the "url" field.

func URLEqualFold

func URLEqualFold(v string) predicate.Media

URLEqualFold applies the EqualFold predicate on the "url" field.

func URLGT

func URLGT(v string) predicate.Media

URLGT applies the GT predicate on the "url" field.

func URLGTE

func URLGTE(v string) predicate.Media

URLGTE applies the GTE predicate on the "url" field.

func URLHasPrefix

func URLHasPrefix(v string) predicate.Media

URLHasPrefix applies the HasPrefix predicate on the "url" field.

func URLHasSuffix

func URLHasSuffix(v string) predicate.Media

URLHasSuffix applies the HasSuffix predicate on the "url" field.

func URLIn

func URLIn(vs ...string) predicate.Media

URLIn applies the In predicate on the "url" field.

func URLLT

func URLLT(v string) predicate.Media

URLLT applies the LT predicate on the "url" field.

func URLLTE

func URLLTE(v string) predicate.Media

URLLTE applies the LTE predicate on the "url" field.

func URLNEQ

func URLNEQ(v string) predicate.Media

URLNEQ applies the NEQ predicate on the "url" field.

func URLNotIn

func URLNotIn(vs ...string) predicate.Media

URLNotIn applies the NotIn predicate on the "url" field.

func UpdatedAt

func UpdatedAt(v time.Time) predicate.Media

UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.

func UpdatedAtEQ

func UpdatedAtEQ(v time.Time) predicate.Media

UpdatedAtEQ applies the EQ predicate on the "updated_at" field.

func UpdatedAtGT

func UpdatedAtGT(v time.Time) predicate.Media

UpdatedAtGT applies the GT predicate on the "updated_at" field.

func UpdatedAtGTE

func UpdatedAtGTE(v time.Time) predicate.Media

UpdatedAtGTE applies the GTE predicate on the "updated_at" field.

func UpdatedAtIn

func UpdatedAtIn(vs ...time.Time) predicate.Media

UpdatedAtIn applies the In predicate on the "updated_at" field.

func UpdatedAtIsNil

func UpdatedAtIsNil() predicate.Media

UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.

func UpdatedAtLT

func UpdatedAtLT(v time.Time) predicate.Media

UpdatedAtLT applies the LT predicate on the "updated_at" field.

func UpdatedAtLTE

func UpdatedAtLTE(v time.Time) predicate.Media

UpdatedAtLTE applies the LTE predicate on the "updated_at" field.

func UpdatedAtNEQ

func UpdatedAtNEQ(v time.Time) predicate.Media

UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.

func UpdatedAtNotIn

func UpdatedAtNotIn(vs ...time.Time) predicate.Media

UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.

func UpdatedAtNotNil

func UpdatedAtNotNil() predicate.Media

UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.

func UpdatedByID

func UpdatedByID(v uuid.UUID) predicate.Media

UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.

func UpdatedByIDEQ

func UpdatedByIDEQ(v uuid.UUID) predicate.Media

UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.

func UpdatedByIDGT

func UpdatedByIDGT(v uuid.UUID) predicate.Media

UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.

func UpdatedByIDGTE

func UpdatedByIDGTE(v uuid.UUID) predicate.Media

UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.

func UpdatedByIDIn

func UpdatedByIDIn(vs ...uuid.UUID) predicate.Media

UpdatedByIDIn applies the In predicate on the "updated_by_id" field.

func UpdatedByIDIsNil

func UpdatedByIDIsNil() predicate.Media

UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.

func UpdatedByIDLT

func UpdatedByIDLT(v uuid.UUID) predicate.Media

UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.

func UpdatedByIDLTE

func UpdatedByIDLTE(v uuid.UUID) predicate.Media

UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.

func UpdatedByIDNEQ

func UpdatedByIDNEQ(v uuid.UUID) predicate.Media

UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.

func UpdatedByIDNotIn

func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.Media

UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.

func UpdatedByIDNotNil

func UpdatedByIDNotNil() predicate.Media

UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

func Width

func Width(v int) predicate.Media

Width applies equality check predicate on the "width" field. It's identical to WidthEQ.

func WidthEQ

func WidthEQ(v int) predicate.Media

WidthEQ applies the EQ predicate on the "width" field.

func WidthGT

func WidthGT(v int) predicate.Media

WidthGT applies the GT predicate on the "width" field.

func WidthGTE

func WidthGTE(v int) predicate.Media

WidthGTE applies the GTE predicate on the "width" field.

func WidthIn

func WidthIn(vs ...int) predicate.Media

WidthIn applies the In predicate on the "width" field.

func WidthIsNil

func WidthIsNil() predicate.Media

WidthIsNil applies the IsNil predicate on the "width" field.

func WidthLT

func WidthLT(v int) predicate.Media

WidthLT applies the LT predicate on the "width" field.

func WidthLTE

func WidthLTE(v int) predicate.Media

WidthLTE applies the LTE predicate on the "width" field.

func WidthNEQ

func WidthNEQ(v int) predicate.Media

WidthNEQ applies the NEQ predicate on the "width" field.

func WidthNotIn

func WidthNotIn(vs ...int) predicate.Media

WidthNotIn applies the NotIn predicate on the "width" field.

func WidthNotNil

func WidthNotNil() predicate.Media

WidthNotNil applies the NotNil predicate on the "width" field.

Types

type OrderOption

type OrderOption func(*sql.Selector)

OrderOption defines the ordering options for the Media queries.

func ByAlternativeText

func ByAlternativeText(opts ...sql.OrderTermOption) OrderOption

ByAlternativeText orders the results by the alternative_text field.

func ByArchivedAt

func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption

ByArchivedAt orders the results by the archived_at field.

func ByCaption

func ByCaption(opts ...sql.OrderTermOption) OrderOption

ByCaption orders the results by the caption field.

func ByCreatedAt

func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption

ByCreatedAt orders the results by the created_at field.

func ByCreatedByID

func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption

ByCreatedByID orders the results by the created_by_id field.

func ByDeletedAt

func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption

ByDeletedAt orders the results by the deleted_at field.

func ByDeletedByID

func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption

ByDeletedByID orders the results by the deleted_by_id field.

func ByExt

func ByExt(opts ...sql.OrderTermOption) OrderOption

ByExt orders the results by the ext field.

func ByFolderPath

func ByFolderPath(opts ...sql.OrderTermOption) OrderOption

ByFolderPath orders the results by the folder_path field.

func ByFormats

func ByFormats(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption

ByFormats orders the results by formats terms.

func ByFormatsCount

func ByFormatsCount(opts ...sql.OrderTermOption) OrderOption

ByFormatsCount orders the results by formats count.

func ByHash

func ByHash(opts ...sql.OrderTermOption) OrderOption

ByHash orders the results by the hash field.

func ByHeight

func ByHeight(opts ...sql.OrderTermOption) OrderOption

ByHeight orders the results by the height field.

func ByID

func ByID(opts ...sql.OrderTermOption) OrderOption

ByID orders the results by the id field.

func ByIsURLSigned

func ByIsURLSigned(opts ...sql.OrderTermOption) OrderOption

ByIsURLSigned orders the results by the is_url_signed field.

func ByLocale

func ByLocale(opts ...sql.OrderTermOption) OrderOption

ByLocale orders the results by the locale field.

func ByMime

func ByMime(opts ...sql.OrderTermOption) OrderOption

ByMime orders the results by the mime field.

func ByName

func ByName(opts ...sql.OrderTermOption) OrderOption

ByName orders the results by the name field.

func ByPreviewURL

func ByPreviewURL(opts ...sql.OrderTermOption) OrderOption

ByPreviewURL orders the results by the preview_url field.

func ByProvider

func ByProvider(opts ...sql.OrderTermOption) OrderOption

ByProvider orders the results by the provider field.

func ByPublishedAt

func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption

ByPublishedAt orders the results by the published_at field.

func BySize

func BySize(opts ...sql.OrderTermOption) OrderOption

BySize orders the results by the size field.

func ByTenantID

func ByTenantID(opts ...sql.OrderTermOption) OrderOption

ByTenantID orders the results by the tenant_id field.

func ByURL

func ByURL(opts ...sql.OrderTermOption) OrderOption

ByURL orders the results by the url field.

func ByUpdatedAt

func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption

ByUpdatedAt orders the results by the updated_at field.

func ByUpdatedByID

func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption

ByUpdatedByID orders the results by the updated_by_id field.

func ByWidth

func ByWidth(opts ...sql.OrderTermOption) OrderOption

ByWidth orders the results by the width field.

Jump to