Documentation
¶
Index ¶
- Constants
- Variables
- func AlternativeText(v string) predicate.Media
- func AlternativeTextContains(v string) predicate.Media
- func AlternativeTextContainsFold(v string) predicate.Media
- func AlternativeTextEQ(v string) predicate.Media
- func AlternativeTextEqualFold(v string) predicate.Media
- func AlternativeTextGT(v string) predicate.Media
- func AlternativeTextGTE(v string) predicate.Media
- func AlternativeTextHasPrefix(v string) predicate.Media
- func AlternativeTextHasSuffix(v string) predicate.Media
- func AlternativeTextIn(vs ...string) predicate.Media
- func AlternativeTextIsNil() predicate.Media
- func AlternativeTextLT(v string) predicate.Media
- func AlternativeTextLTE(v string) predicate.Media
- func AlternativeTextNEQ(v string) predicate.Media
- func AlternativeTextNotIn(vs ...string) predicate.Media
- func AlternativeTextNotNil() predicate.Media
- func And(predicates ...predicate.Media) predicate.Media
- func ArchivedAt(v time.Time) predicate.Media
- func ArchivedAtEQ(v time.Time) predicate.Media
- func ArchivedAtGT(v time.Time) predicate.Media
- func ArchivedAtGTE(v time.Time) predicate.Media
- func ArchivedAtIn(vs ...time.Time) predicate.Media
- func ArchivedAtIsNil() predicate.Media
- func ArchivedAtLT(v time.Time) predicate.Media
- func ArchivedAtLTE(v time.Time) predicate.Media
- func ArchivedAtNEQ(v time.Time) predicate.Media
- func ArchivedAtNotIn(vs ...time.Time) predicate.Media
- func ArchivedAtNotNil() predicate.Media
- func Caption(v string) predicate.Media
- func CaptionContains(v string) predicate.Media
- func CaptionContainsFold(v string) predicate.Media
- func CaptionEQ(v string) predicate.Media
- func CaptionEqualFold(v string) predicate.Media
- func CaptionGT(v string) predicate.Media
- func CaptionGTE(v string) predicate.Media
- func CaptionHasPrefix(v string) predicate.Media
- func CaptionHasSuffix(v string) predicate.Media
- func CaptionIn(vs ...string) predicate.Media
- func CaptionIsNil() predicate.Media
- func CaptionLT(v string) predicate.Media
- func CaptionLTE(v string) predicate.Media
- func CaptionNEQ(v string) predicate.Media
- func CaptionNotIn(vs ...string) predicate.Media
- func CaptionNotNil() predicate.Media
- func CreatedAt(v time.Time) predicate.Media
- func CreatedAtEQ(v time.Time) predicate.Media
- func CreatedAtGT(v time.Time) predicate.Media
- func CreatedAtGTE(v time.Time) predicate.Media
- func CreatedAtIn(vs ...time.Time) predicate.Media
- func CreatedAtIsNil() predicate.Media
- func CreatedAtLT(v time.Time) predicate.Media
- func CreatedAtLTE(v time.Time) predicate.Media
- func CreatedAtNEQ(v time.Time) predicate.Media
- func CreatedAtNotIn(vs ...time.Time) predicate.Media
- func CreatedAtNotNil() predicate.Media
- func CreatedByID(v uuid.UUID) predicate.Media
- func CreatedByIDEQ(v uuid.UUID) predicate.Media
- func CreatedByIDGT(v uuid.UUID) predicate.Media
- func CreatedByIDGTE(v uuid.UUID) predicate.Media
- func CreatedByIDIn(vs ...uuid.UUID) predicate.Media
- func CreatedByIDIsNil() predicate.Media
- func CreatedByIDLT(v uuid.UUID) predicate.Media
- func CreatedByIDLTE(v uuid.UUID) predicate.Media
- func CreatedByIDNEQ(v uuid.UUID) predicate.Media
- func CreatedByIDNotIn(vs ...uuid.UUID) predicate.Media
- func CreatedByIDNotNil() predicate.Media
- func DeletedAt(v time.Time) predicate.Media
- func DeletedAtEQ(v time.Time) predicate.Media
- func DeletedAtGT(v time.Time) predicate.Media
- func DeletedAtGTE(v time.Time) predicate.Media
- func DeletedAtIn(vs ...time.Time) predicate.Media
- func DeletedAtIsNil() predicate.Media
- func DeletedAtLT(v time.Time) predicate.Media
- func DeletedAtLTE(v time.Time) predicate.Media
- func DeletedAtNEQ(v time.Time) predicate.Media
- func DeletedAtNotIn(vs ...time.Time) predicate.Media
- func DeletedAtNotNil() predicate.Media
- func DeletedByID(v uuid.UUID) predicate.Media
- func DeletedByIDEQ(v uuid.UUID) predicate.Media
- func DeletedByIDGT(v uuid.UUID) predicate.Media
- func DeletedByIDGTE(v uuid.UUID) predicate.Media
- func DeletedByIDIn(vs ...uuid.UUID) predicate.Media
- func DeletedByIDIsNil() predicate.Media
- func DeletedByIDLT(v uuid.UUID) predicate.Media
- func DeletedByIDLTE(v uuid.UUID) predicate.Media
- func DeletedByIDNEQ(v uuid.UUID) predicate.Media
- func DeletedByIDNotIn(vs ...uuid.UUID) predicate.Media
- func DeletedByIDNotNil() predicate.Media
- func Ext(v string) predicate.Media
- func ExtContains(v string) predicate.Media
- func ExtContainsFold(v string) predicate.Media
- func ExtEQ(v string) predicate.Media
- func ExtEqualFold(v string) predicate.Media
- func ExtGT(v string) predicate.Media
- func ExtGTE(v string) predicate.Media
- func ExtHasPrefix(v string) predicate.Media
- func ExtHasSuffix(v string) predicate.Media
- func ExtIn(vs ...string) predicate.Media
- func ExtIsNil() predicate.Media
- func ExtLT(v string) predicate.Media
- func ExtLTE(v string) predicate.Media
- func ExtNEQ(v string) predicate.Media
- func ExtNotIn(vs ...string) predicate.Media
- func ExtNotNil() predicate.Media
- func FolderPath(v string) predicate.Media
- func FolderPathContains(v string) predicate.Media
- func FolderPathContainsFold(v string) predicate.Media
- func FolderPathEQ(v string) predicate.Media
- func FolderPathEqualFold(v string) predicate.Media
- func FolderPathGT(v string) predicate.Media
- func FolderPathGTE(v string) predicate.Media
- func FolderPathHasPrefix(v string) predicate.Media
- func FolderPathHasSuffix(v string) predicate.Media
- func FolderPathIn(vs ...string) predicate.Media
- func FolderPathIsNil() predicate.Media
- func FolderPathLT(v string) predicate.Media
- func FolderPathLTE(v string) predicate.Media
- func FolderPathNEQ(v string) predicate.Media
- func FolderPathNotIn(vs ...string) predicate.Media
- func FolderPathNotNil() predicate.Media
- func HasFormats() predicate.Media
- func HasFormatsWith(preds ...predicate.MediaFormat) predicate.Media
- func Hash(v string) predicate.Media
- func HashContains(v string) predicate.Media
- func HashContainsFold(v string) predicate.Media
- func HashEQ(v string) predicate.Media
- func HashEqualFold(v string) predicate.Media
- func HashGT(v string) predicate.Media
- func HashGTE(v string) predicate.Media
- func HashHasPrefix(v string) predicate.Media
- func HashHasSuffix(v string) predicate.Media
- func HashIn(vs ...string) predicate.Media
- func HashIsNil() predicate.Media
- func HashLT(v string) predicate.Media
- func HashLTE(v string) predicate.Media
- func HashNEQ(v string) predicate.Media
- func HashNotIn(vs ...string) predicate.Media
- func HashNotNil() predicate.Media
- func Height(v int) predicate.Media
- func HeightEQ(v int) predicate.Media
- func HeightGT(v int) predicate.Media
- func HeightGTE(v int) predicate.Media
- func HeightIn(vs ...int) predicate.Media
- func HeightIsNil() predicate.Media
- func HeightLT(v int) predicate.Media
- func HeightLTE(v int) predicate.Media
- func HeightNEQ(v int) predicate.Media
- func HeightNotIn(vs ...int) predicate.Media
- func HeightNotNil() predicate.Media
- func ID(id uuid.UUID) predicate.Media
- func IDEQ(id uuid.UUID) predicate.Media
- func IDGT(id uuid.UUID) predicate.Media
- func IDGTE(id uuid.UUID) predicate.Media
- func IDIn(ids ...uuid.UUID) predicate.Media
- func IDLT(id uuid.UUID) predicate.Media
- func IDLTE(id uuid.UUID) predicate.Media
- func IDNEQ(id uuid.UUID) predicate.Media
- func IDNotIn(ids ...uuid.UUID) predicate.Media
- func IsURLSigned(v bool) predicate.Media
- func IsURLSignedEQ(v bool) predicate.Media
- func IsURLSignedIsNil() predicate.Media
- func IsURLSignedNEQ(v bool) predicate.Media
- func IsURLSignedNotNil() predicate.Media
- func Locale(v string) predicate.Media
- func LocaleContains(v string) predicate.Media
- func LocaleContainsFold(v string) predicate.Media
- func LocaleEQ(v string) predicate.Media
- func LocaleEqualFold(v string) predicate.Media
- func LocaleGT(v string) predicate.Media
- func LocaleGTE(v string) predicate.Media
- func LocaleHasPrefix(v string) predicate.Media
- func LocaleHasSuffix(v string) predicate.Media
- func LocaleIn(vs ...string) predicate.Media
- func LocaleIsNil() predicate.Media
- func LocaleLT(v string) predicate.Media
- func LocaleLTE(v string) predicate.Media
- func LocaleNEQ(v string) predicate.Media
- func LocaleNotIn(vs ...string) predicate.Media
- func LocaleNotNil() predicate.Media
- func Mime(v string) predicate.Media
- func MimeContains(v string) predicate.Media
- func MimeContainsFold(v string) predicate.Media
- func MimeEQ(v string) predicate.Media
- func MimeEqualFold(v string) predicate.Media
- func MimeGT(v string) predicate.Media
- func MimeGTE(v string) predicate.Media
- func MimeHasPrefix(v string) predicate.Media
- func MimeHasSuffix(v string) predicate.Media
- func MimeIn(vs ...string) predicate.Media
- func MimeIsNil() predicate.Media
- func MimeLT(v string) predicate.Media
- func MimeLTE(v string) predicate.Media
- func MimeNEQ(v string) predicate.Media
- func MimeNotIn(vs ...string) predicate.Media
- func MimeNotNil() predicate.Media
- func Name(v string) predicate.Media
- func NameContains(v string) predicate.Media
- func NameContainsFold(v string) predicate.Media
- func NameEQ(v string) predicate.Media
- func NameEqualFold(v string) predicate.Media
- func NameGT(v string) predicate.Media
- func NameGTE(v string) predicate.Media
- func NameHasPrefix(v string) predicate.Media
- func NameHasSuffix(v string) predicate.Media
- func NameIn(vs ...string) predicate.Media
- func NameLT(v string) predicate.Media
- func NameLTE(v string) predicate.Media
- func NameNEQ(v string) predicate.Media
- func NameNotIn(vs ...string) predicate.Media
- func Not(p predicate.Media) predicate.Media
- func Or(predicates ...predicate.Media) predicate.Media
- func PreviewURL(v string) predicate.Media
- func PreviewURLContains(v string) predicate.Media
- func PreviewURLContainsFold(v string) predicate.Media
- func PreviewURLEQ(v string) predicate.Media
- func PreviewURLEqualFold(v string) predicate.Media
- func PreviewURLGT(v string) predicate.Media
- func PreviewURLGTE(v string) predicate.Media
- func PreviewURLHasPrefix(v string) predicate.Media
- func PreviewURLHasSuffix(v string) predicate.Media
- func PreviewURLIn(vs ...string) predicate.Media
- func PreviewURLIsNil() predicate.Media
- func PreviewURLLT(v string) predicate.Media
- func PreviewURLLTE(v string) predicate.Media
- func PreviewURLNEQ(v string) predicate.Media
- func PreviewURLNotIn(vs ...string) predicate.Media
- func PreviewURLNotNil() predicate.Media
- func Provider(v string) predicate.Media
- func ProviderContains(v string) predicate.Media
- func ProviderContainsFold(v string) predicate.Media
- func ProviderEQ(v string) predicate.Media
- func ProviderEqualFold(v string) predicate.Media
- func ProviderGT(v string) predicate.Media
- func ProviderGTE(v string) predicate.Media
- func ProviderHasPrefix(v string) predicate.Media
- func ProviderHasSuffix(v string) predicate.Media
- func ProviderIn(vs ...string) predicate.Media
- func ProviderIsNil() predicate.Media
- func ProviderLT(v string) predicate.Media
- func ProviderLTE(v string) predicate.Media
- func ProviderMetadataIsNil() predicate.Media
- func ProviderMetadataNotNil() predicate.Media
- func ProviderNEQ(v string) predicate.Media
- func ProviderNotIn(vs ...string) predicate.Media
- func ProviderNotNil() predicate.Media
- func PublishedAt(v time.Time) predicate.Media
- func PublishedAtEQ(v time.Time) predicate.Media
- func PublishedAtGT(v time.Time) predicate.Media
- func PublishedAtGTE(v time.Time) predicate.Media
- func PublishedAtIn(vs ...time.Time) predicate.Media
- func PublishedAtIsNil() predicate.Media
- func PublishedAtLT(v time.Time) predicate.Media
- func PublishedAtLTE(v time.Time) predicate.Media
- func PublishedAtNEQ(v time.Time) predicate.Media
- func PublishedAtNotIn(vs ...time.Time) predicate.Media
- func PublishedAtNotNil() predicate.Media
- func Size(v float64) predicate.Media
- func SizeEQ(v float64) predicate.Media
- func SizeGT(v float64) predicate.Media
- func SizeGTE(v float64) predicate.Media
- func SizeIn(vs ...float64) predicate.Media
- func SizeIsNil() predicate.Media
- func SizeLT(v float64) predicate.Media
- func SizeLTE(v float64) predicate.Media
- func SizeNEQ(v float64) predicate.Media
- func SizeNotIn(vs ...float64) predicate.Media
- func SizeNotNil() predicate.Media
- func TenantID(v string) predicate.Media
- func TenantIDContains(v string) predicate.Media
- func TenantIDContainsFold(v string) predicate.Media
- func TenantIDEQ(v string) predicate.Media
- func TenantIDEqualFold(v string) predicate.Media
- func TenantIDGT(v string) predicate.Media
- func TenantIDGTE(v string) predicate.Media
- func TenantIDHasPrefix(v string) predicate.Media
- func TenantIDHasSuffix(v string) predicate.Media
- func TenantIDIn(vs ...string) predicate.Media
- func TenantIDLT(v string) predicate.Media
- func TenantIDLTE(v string) predicate.Media
- func TenantIDNEQ(v string) predicate.Media
- func TenantIDNotIn(vs ...string) predicate.Media
- func URL(v string) predicate.Media
- func URLContains(v string) predicate.Media
- func URLContainsFold(v string) predicate.Media
- func URLEQ(v string) predicate.Media
- func URLEqualFold(v string) predicate.Media
- func URLGT(v string) predicate.Media
- func URLGTE(v string) predicate.Media
- func URLHasPrefix(v string) predicate.Media
- func URLHasSuffix(v string) predicate.Media
- func URLIn(vs ...string) predicate.Media
- func URLLT(v string) predicate.Media
- func URLLTE(v string) predicate.Media
- func URLNEQ(v string) predicate.Media
- func URLNotIn(vs ...string) predicate.Media
- func UpdatedAt(v time.Time) predicate.Media
- func UpdatedAtEQ(v time.Time) predicate.Media
- func UpdatedAtGT(v time.Time) predicate.Media
- func UpdatedAtGTE(v time.Time) predicate.Media
- func UpdatedAtIn(vs ...time.Time) predicate.Media
- func UpdatedAtIsNil() predicate.Media
- func UpdatedAtLT(v time.Time) predicate.Media
- func UpdatedAtLTE(v time.Time) predicate.Media
- func UpdatedAtNEQ(v time.Time) predicate.Media
- func UpdatedAtNotIn(vs ...time.Time) predicate.Media
- func UpdatedAtNotNil() predicate.Media
- func UpdatedByID(v uuid.UUID) predicate.Media
- func UpdatedByIDEQ(v uuid.UUID) predicate.Media
- func UpdatedByIDGT(v uuid.UUID) predicate.Media
- func UpdatedByIDGTE(v uuid.UUID) predicate.Media
- func UpdatedByIDIn(vs ...uuid.UUID) predicate.Media
- func UpdatedByIDIsNil() predicate.Media
- func UpdatedByIDLT(v uuid.UUID) predicate.Media
- func UpdatedByIDLTE(v uuid.UUID) predicate.Media
- func UpdatedByIDNEQ(v uuid.UUID) predicate.Media
- func UpdatedByIDNotIn(vs ...uuid.UUID) predicate.Media
- func UpdatedByIDNotNil() predicate.Media
- func ValidColumn(column string) bool
- func Width(v int) predicate.Media
- func WidthEQ(v int) predicate.Media
- func WidthGT(v int) predicate.Media
- func WidthGTE(v int) predicate.Media
- func WidthIn(vs ...int) predicate.Media
- func WidthIsNil() predicate.Media
- func WidthLT(v int) predicate.Media
- func WidthLTE(v int) predicate.Media
- func WidthNEQ(v int) predicate.Media
- func WidthNotIn(vs ...int) predicate.Media
- func WidthNotNil() predicate.Media
- type OrderOption
- func ByAlternativeText(opts ...sql.OrderTermOption) OrderOption
- func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCaption(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
- func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
- func ByExt(opts ...sql.OrderTermOption) OrderOption
- func ByFolderPath(opts ...sql.OrderTermOption) OrderOption
- func ByFormats(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByFormatsCount(opts ...sql.OrderTermOption) OrderOption
- func ByHash(opts ...sql.OrderTermOption) OrderOption
- func ByHeight(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByIsURLSigned(opts ...sql.OrderTermOption) OrderOption
- func ByLocale(opts ...sql.OrderTermOption) OrderOption
- func ByMime(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByPreviewURL(opts ...sql.OrderTermOption) OrderOption
- func ByProvider(opts ...sql.OrderTermOption) OrderOption
- func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
- func BySize(opts ...sql.OrderTermOption) OrderOption
- func ByTenantID(opts ...sql.OrderTermOption) OrderOption
- func ByURL(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
- func ByWidth(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the media type in the database. Label = "media" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldTenantID holds the string denoting the tenant_id field in the database. FieldTenantID = "tenant_id" // FieldCreatedByID holds the string denoting the created_by_id field in the database. FieldCreatedByID = "created_by_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedByID holds the string denoting the updated_by_id field in the database. FieldUpdatedByID = "updated_by_id" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // FieldDeletedByID holds the string denoting the deleted_by_id field in the database. FieldDeletedByID = "deleted_by_id" // FieldDeletedAt holds the string denoting the deleted_at field in the database. FieldDeletedAt = "deleted_at" // FieldPublishedAt holds the string denoting the published_at field in the database. FieldPublishedAt = "published_at" // FieldArchivedAt holds the string denoting the archived_at field in the database. FieldArchivedAt = "archived_at" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldAlternativeText holds the string denoting the alternative_text field in the database. FieldAlternativeText = "alternative_text" // FieldCaption holds the string denoting the caption field in the database. FieldCaption = "caption" // FieldWidth holds the string denoting the width field in the database. FieldWidth = "width" // FieldHeight holds the string denoting the height field in the database. FieldHeight = "height" // FieldHash holds the string denoting the hash field in the database. FieldHash = "hash" // FieldExt holds the string denoting the ext field in the database. FieldExt = "ext" // FieldMime holds the string denoting the mime field in the database. FieldMime = "mime" // FieldSize holds the string denoting the size field in the database. FieldSize = "size" // FieldURL holds the string denoting the url field in the database. FieldURL = "url" // FieldPreviewURL holds the string denoting the preview_url field in the database. FieldPreviewURL = "preview_url" // FieldProvider holds the string denoting the provider field in the database. FieldProvider = "provider" // FieldProviderMetadata holds the string denoting the provider_metadata field in the database. FieldProviderMetadata = "provider_metadata" // FieldFolderPath holds the string denoting the folder_path field in the database. FieldFolderPath = "folder_path" // FieldLocale holds the string denoting the locale field in the database. FieldLocale = "locale" // FieldIsURLSigned holds the string denoting the is_url_signed field in the database. FieldIsURLSigned = "is_url_signed" // EdgeFormats holds the string denoting the formats edge name in mutations. EdgeFormats = "formats" // Table holds the table name of the media in the database. Table = "media" // FormatsTable is the table that holds the formats relation/edge. FormatsTable = "media_formats" // FormatsInverseTable is the table name for the MediaFormat entity. // It exists in this package in order to avoid circular dependency with the "mediaformat" package. FormatsInverseTable = "media_formats" // FormatsColumn is the table column denoting the formats relation/edge. FormatsColumn = "media_id" )
Variables ¶
var ( // DefaultTenantID holds the default value on creation for the "tenant_id" field. DefaultTenantID string // TenantIDValidator is a validator for the "tenant_id" field. It is called by the builders before save. TenantIDValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // URLValidator is a validator for the "url" field. It is called by the builders before save. URLValidator func(string) error // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldTenantID, FieldCreatedByID, FieldCreatedAt, FieldUpdatedByID, FieldUpdatedAt, FieldDeletedByID, FieldDeletedAt, FieldPublishedAt, FieldArchivedAt, FieldName, FieldAlternativeText, FieldCaption, FieldWidth, FieldHeight, FieldHash, FieldExt, FieldMime, FieldSize, FieldURL, FieldPreviewURL, FieldProvider, FieldProviderMetadata, FieldFolderPath, FieldLocale, FieldIsURLSigned, }
Columns holds all SQL columns for media fields.
Functions ¶
func AlternativeText ¶
AlternativeText applies equality check predicate on the "alternative_text" field. It's identical to AlternativeTextEQ.
func AlternativeTextContains ¶
AlternativeTextContains applies the Contains predicate on the "alternative_text" field.
func AlternativeTextContainsFold ¶
AlternativeTextContainsFold applies the ContainsFold predicate on the "alternative_text" field.
func AlternativeTextEQ ¶
AlternativeTextEQ applies the EQ predicate on the "alternative_text" field.
func AlternativeTextEqualFold ¶
AlternativeTextEqualFold applies the EqualFold predicate on the "alternative_text" field.
func AlternativeTextGT ¶
AlternativeTextGT applies the GT predicate on the "alternative_text" field.
func AlternativeTextGTE ¶
AlternativeTextGTE applies the GTE predicate on the "alternative_text" field.
func AlternativeTextHasPrefix ¶
AlternativeTextHasPrefix applies the HasPrefix predicate on the "alternative_text" field.
func AlternativeTextHasSuffix ¶
AlternativeTextHasSuffix applies the HasSuffix predicate on the "alternative_text" field.
func AlternativeTextIn ¶
AlternativeTextIn applies the In predicate on the "alternative_text" field.
func AlternativeTextIsNil ¶
AlternativeTextIsNil applies the IsNil predicate on the "alternative_text" field.
func AlternativeTextLT ¶
AlternativeTextLT applies the LT predicate on the "alternative_text" field.
func AlternativeTextLTE ¶
AlternativeTextLTE applies the LTE predicate on the "alternative_text" field.
func AlternativeTextNEQ ¶
AlternativeTextNEQ applies the NEQ predicate on the "alternative_text" field.
func AlternativeTextNotIn ¶
AlternativeTextNotIn applies the NotIn predicate on the "alternative_text" field.
func AlternativeTextNotNil ¶
AlternativeTextNotNil applies the NotNil predicate on the "alternative_text" field.
func ArchivedAt ¶
ArchivedAt applies equality check predicate on the "archived_at" field. It's identical to ArchivedAtEQ.
func ArchivedAtEQ ¶
ArchivedAtEQ applies the EQ predicate on the "archived_at" field.
func ArchivedAtGT ¶
ArchivedAtGT applies the GT predicate on the "archived_at" field.
func ArchivedAtGTE ¶
ArchivedAtGTE applies the GTE predicate on the "archived_at" field.
func ArchivedAtIn ¶
ArchivedAtIn applies the In predicate on the "archived_at" field.
func ArchivedAtIsNil ¶
ArchivedAtIsNil applies the IsNil predicate on the "archived_at" field.
func ArchivedAtLT ¶
ArchivedAtLT applies the LT predicate on the "archived_at" field.
func ArchivedAtLTE ¶
ArchivedAtLTE applies the LTE predicate on the "archived_at" field.
func ArchivedAtNEQ ¶
ArchivedAtNEQ applies the NEQ predicate on the "archived_at" field.
func ArchivedAtNotIn ¶
ArchivedAtNotIn applies the NotIn predicate on the "archived_at" field.
func ArchivedAtNotNil ¶
ArchivedAtNotNil applies the NotNil predicate on the "archived_at" field.
func Caption ¶
Caption applies equality check predicate on the "caption" field. It's identical to CaptionEQ.
func CaptionContains ¶
CaptionContains applies the Contains predicate on the "caption" field.
func CaptionContainsFold ¶
CaptionContainsFold applies the ContainsFold predicate on the "caption" field.
func CaptionEqualFold ¶
CaptionEqualFold applies the EqualFold predicate on the "caption" field.
func CaptionGTE ¶
CaptionGTE applies the GTE predicate on the "caption" field.
func CaptionHasPrefix ¶
CaptionHasPrefix applies the HasPrefix predicate on the "caption" field.
func CaptionHasSuffix ¶
CaptionHasSuffix applies the HasSuffix predicate on the "caption" field.
func CaptionIsNil ¶
CaptionIsNil applies the IsNil predicate on the "caption" field.
func CaptionLTE ¶
CaptionLTE applies the LTE predicate on the "caption" field.
func CaptionNEQ ¶
CaptionNEQ applies the NEQ predicate on the "caption" field.
func CaptionNotIn ¶
CaptionNotIn applies the NotIn predicate on the "caption" field.
func CaptionNotNil ¶
CaptionNotNil applies the NotNil predicate on the "caption" field.
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtIsNil ¶
CreatedAtIsNil applies the IsNil predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func CreatedAtNotNil ¶
CreatedAtNotNil applies the NotNil predicate on the "created_at" field.
func CreatedByID ¶
CreatedByID applies equality check predicate on the "created_by_id" field. It's identical to CreatedByIDEQ.
func CreatedByIDEQ ¶
CreatedByIDEQ applies the EQ predicate on the "created_by_id" field.
func CreatedByIDGT ¶
CreatedByIDGT applies the GT predicate on the "created_by_id" field.
func CreatedByIDGTE ¶
CreatedByIDGTE applies the GTE predicate on the "created_by_id" field.
func CreatedByIDIn ¶
CreatedByIDIn applies the In predicate on the "created_by_id" field.
func CreatedByIDIsNil ¶
CreatedByIDIsNil applies the IsNil predicate on the "created_by_id" field.
func CreatedByIDLT ¶
CreatedByIDLT applies the LT predicate on the "created_by_id" field.
func CreatedByIDLTE ¶
CreatedByIDLTE applies the LTE predicate on the "created_by_id" field.
func CreatedByIDNEQ ¶
CreatedByIDNEQ applies the NEQ predicate on the "created_by_id" field.
func CreatedByIDNotIn ¶
CreatedByIDNotIn applies the NotIn predicate on the "created_by_id" field.
func CreatedByIDNotNil ¶
CreatedByIDNotNil applies the NotNil predicate on the "created_by_id" field.
func DeletedAt ¶
DeletedAt applies equality check predicate on the "deleted_at" field. It's identical to DeletedAtEQ.
func DeletedAtEQ ¶
DeletedAtEQ applies the EQ predicate on the "deleted_at" field.
func DeletedAtGT ¶
DeletedAtGT applies the GT predicate on the "deleted_at" field.
func DeletedAtGTE ¶
DeletedAtGTE applies the GTE predicate on the "deleted_at" field.
func DeletedAtIn ¶
DeletedAtIn applies the In predicate on the "deleted_at" field.
func DeletedAtIsNil ¶
DeletedAtIsNil applies the IsNil predicate on the "deleted_at" field.
func DeletedAtLT ¶
DeletedAtLT applies the LT predicate on the "deleted_at" field.
func DeletedAtLTE ¶
DeletedAtLTE applies the LTE predicate on the "deleted_at" field.
func DeletedAtNEQ ¶
DeletedAtNEQ applies the NEQ predicate on the "deleted_at" field.
func DeletedAtNotIn ¶
DeletedAtNotIn applies the NotIn predicate on the "deleted_at" field.
func DeletedAtNotNil ¶
DeletedAtNotNil applies the NotNil predicate on the "deleted_at" field.
func DeletedByID ¶
DeletedByID applies equality check predicate on the "deleted_by_id" field. It's identical to DeletedByIDEQ.
func DeletedByIDEQ ¶
DeletedByIDEQ applies the EQ predicate on the "deleted_by_id" field.
func DeletedByIDGT ¶
DeletedByIDGT applies the GT predicate on the "deleted_by_id" field.
func DeletedByIDGTE ¶
DeletedByIDGTE applies the GTE predicate on the "deleted_by_id" field.
func DeletedByIDIn ¶
DeletedByIDIn applies the In predicate on the "deleted_by_id" field.
func DeletedByIDIsNil ¶
DeletedByIDIsNil applies the IsNil predicate on the "deleted_by_id" field.
func DeletedByIDLT ¶
DeletedByIDLT applies the LT predicate on the "deleted_by_id" field.
func DeletedByIDLTE ¶
DeletedByIDLTE applies the LTE predicate on the "deleted_by_id" field.
func DeletedByIDNEQ ¶
DeletedByIDNEQ applies the NEQ predicate on the "deleted_by_id" field.
func DeletedByIDNotIn ¶
DeletedByIDNotIn applies the NotIn predicate on the "deleted_by_id" field.
func DeletedByIDNotNil ¶
DeletedByIDNotNil applies the NotNil predicate on the "deleted_by_id" field.
func ExtContains ¶
ExtContains applies the Contains predicate on the "ext" field.
func ExtContainsFold ¶
ExtContainsFold applies the ContainsFold predicate on the "ext" field.
func ExtEqualFold ¶
ExtEqualFold applies the EqualFold predicate on the "ext" field.
func ExtHasPrefix ¶
ExtHasPrefix applies the HasPrefix predicate on the "ext" field.
func ExtHasSuffix ¶
ExtHasSuffix applies the HasSuffix predicate on the "ext" field.
func FolderPath ¶
FolderPath applies equality check predicate on the "folder_path" field. It's identical to FolderPathEQ.
func FolderPathContains ¶
FolderPathContains applies the Contains predicate on the "folder_path" field.
func FolderPathContainsFold ¶
FolderPathContainsFold applies the ContainsFold predicate on the "folder_path" field.
func FolderPathEQ ¶
FolderPathEQ applies the EQ predicate on the "folder_path" field.
func FolderPathEqualFold ¶
FolderPathEqualFold applies the EqualFold predicate on the "folder_path" field.
func FolderPathGT ¶
FolderPathGT applies the GT predicate on the "folder_path" field.
func FolderPathGTE ¶
FolderPathGTE applies the GTE predicate on the "folder_path" field.
func FolderPathHasPrefix ¶
FolderPathHasPrefix applies the HasPrefix predicate on the "folder_path" field.
func FolderPathHasSuffix ¶
FolderPathHasSuffix applies the HasSuffix predicate on the "folder_path" field.
func FolderPathIn ¶
FolderPathIn applies the In predicate on the "folder_path" field.
func FolderPathIsNil ¶
FolderPathIsNil applies the IsNil predicate on the "folder_path" field.
func FolderPathLT ¶
FolderPathLT applies the LT predicate on the "folder_path" field.
func FolderPathLTE ¶
FolderPathLTE applies the LTE predicate on the "folder_path" field.
func FolderPathNEQ ¶
FolderPathNEQ applies the NEQ predicate on the "folder_path" field.
func FolderPathNotIn ¶
FolderPathNotIn applies the NotIn predicate on the "folder_path" field.
func FolderPathNotNil ¶
FolderPathNotNil applies the NotNil predicate on the "folder_path" field.
func HasFormats ¶
HasFormats applies the HasEdge predicate on the "formats" edge.
func HasFormatsWith ¶
func HasFormatsWith(preds ...predicate.MediaFormat) predicate.Media
HasFormatsWith applies the HasEdge predicate on the "formats" edge with a given conditions (other predicates).
func HashContains ¶
HashContains applies the Contains predicate on the "hash" field.
func HashContainsFold ¶
HashContainsFold applies the ContainsFold predicate on the "hash" field.
func HashEqualFold ¶
HashEqualFold applies the EqualFold predicate on the "hash" field.
func HashHasPrefix ¶
HashHasPrefix applies the HasPrefix predicate on the "hash" field.
func HashHasSuffix ¶
HashHasSuffix applies the HasSuffix predicate on the "hash" field.
func HashNotNil ¶
HashNotNil applies the NotNil predicate on the "hash" field.
func Height ¶
Height applies equality check predicate on the "height" field. It's identical to HeightEQ.
func HeightIsNil ¶
HeightIsNil applies the IsNil predicate on the "height" field.
func HeightNotIn ¶
HeightNotIn applies the NotIn predicate on the "height" field.
func HeightNotNil ¶
HeightNotNil applies the NotNil predicate on the "height" field.
func IsURLSigned ¶
IsURLSigned applies equality check predicate on the "is_url_signed" field. It's identical to IsURLSignedEQ.
func IsURLSignedEQ ¶
IsURLSignedEQ applies the EQ predicate on the "is_url_signed" field.
func IsURLSignedIsNil ¶
IsURLSignedIsNil applies the IsNil predicate on the "is_url_signed" field.
func IsURLSignedNEQ ¶
IsURLSignedNEQ applies the NEQ predicate on the "is_url_signed" field.
func IsURLSignedNotNil ¶
IsURLSignedNotNil applies the NotNil predicate on the "is_url_signed" field.
func Locale ¶
Locale applies equality check predicate on the "locale" field. It's identical to LocaleEQ.
func LocaleContains ¶
LocaleContains applies the Contains predicate on the "locale" field.
func LocaleContainsFold ¶
LocaleContainsFold applies the ContainsFold predicate on the "locale" field.
func LocaleEqualFold ¶
LocaleEqualFold applies the EqualFold predicate on the "locale" field.
func LocaleHasPrefix ¶
LocaleHasPrefix applies the HasPrefix predicate on the "locale" field.
func LocaleHasSuffix ¶
LocaleHasSuffix applies the HasSuffix predicate on the "locale" field.
func LocaleIsNil ¶
LocaleIsNil applies the IsNil predicate on the "locale" field.
func LocaleNotIn ¶
LocaleNotIn applies the NotIn predicate on the "locale" field.
func LocaleNotNil ¶
LocaleNotNil applies the NotNil predicate on the "locale" field.
func MimeContains ¶
MimeContains applies the Contains predicate on the "mime" field.
func MimeContainsFold ¶
MimeContainsFold applies the ContainsFold predicate on the "mime" field.
func MimeEqualFold ¶
MimeEqualFold applies the EqualFold predicate on the "mime" field.
func MimeHasPrefix ¶
MimeHasPrefix applies the HasPrefix predicate on the "mime" field.
func MimeHasSuffix ¶
MimeHasSuffix applies the HasSuffix predicate on the "mime" field.
func MimeNotNil ¶
MimeNotNil applies the NotNil predicate on the "mime" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func PreviewURL ¶
PreviewURL applies equality check predicate on the "preview_url" field. It's identical to PreviewURLEQ.
func PreviewURLContains ¶
PreviewURLContains applies the Contains predicate on the "preview_url" field.
func PreviewURLContainsFold ¶
PreviewURLContainsFold applies the ContainsFold predicate on the "preview_url" field.
func PreviewURLEQ ¶
PreviewURLEQ applies the EQ predicate on the "preview_url" field.
func PreviewURLEqualFold ¶
PreviewURLEqualFold applies the EqualFold predicate on the "preview_url" field.
func PreviewURLGT ¶
PreviewURLGT applies the GT predicate on the "preview_url" field.
func PreviewURLGTE ¶
PreviewURLGTE applies the GTE predicate on the "preview_url" field.
func PreviewURLHasPrefix ¶
PreviewURLHasPrefix applies the HasPrefix predicate on the "preview_url" field.
func PreviewURLHasSuffix ¶
PreviewURLHasSuffix applies the HasSuffix predicate on the "preview_url" field.
func PreviewURLIn ¶
PreviewURLIn applies the In predicate on the "preview_url" field.
func PreviewURLIsNil ¶
PreviewURLIsNil applies the IsNil predicate on the "preview_url" field.
func PreviewURLLT ¶
PreviewURLLT applies the LT predicate on the "preview_url" field.
func PreviewURLLTE ¶
PreviewURLLTE applies the LTE predicate on the "preview_url" field.
func PreviewURLNEQ ¶
PreviewURLNEQ applies the NEQ predicate on the "preview_url" field.
func PreviewURLNotIn ¶
PreviewURLNotIn applies the NotIn predicate on the "preview_url" field.
func PreviewURLNotNil ¶
PreviewURLNotNil applies the NotNil predicate on the "preview_url" field.
func Provider ¶
Provider applies equality check predicate on the "provider" field. It's identical to ProviderEQ.
func ProviderContains ¶
ProviderContains applies the Contains predicate on the "provider" field.
func ProviderContainsFold ¶
ProviderContainsFold applies the ContainsFold predicate on the "provider" field.
func ProviderEQ ¶
ProviderEQ applies the EQ predicate on the "provider" field.
func ProviderEqualFold ¶
ProviderEqualFold applies the EqualFold predicate on the "provider" field.
func ProviderGT ¶
ProviderGT applies the GT predicate on the "provider" field.
func ProviderGTE ¶
ProviderGTE applies the GTE predicate on the "provider" field.
func ProviderHasPrefix ¶
ProviderHasPrefix applies the HasPrefix predicate on the "provider" field.
func ProviderHasSuffix ¶
ProviderHasSuffix applies the HasSuffix predicate on the "provider" field.
func ProviderIn ¶
ProviderIn applies the In predicate on the "provider" field.
func ProviderIsNil ¶
ProviderIsNil applies the IsNil predicate on the "provider" field.
func ProviderLT ¶
ProviderLT applies the LT predicate on the "provider" field.
func ProviderLTE ¶
ProviderLTE applies the LTE predicate on the "provider" field.
func ProviderMetadataIsNil ¶
ProviderMetadataIsNil applies the IsNil predicate on the "provider_metadata" field.
func ProviderMetadataNotNil ¶
ProviderMetadataNotNil applies the NotNil predicate on the "provider_metadata" field.
func ProviderNEQ ¶
ProviderNEQ applies the NEQ predicate on the "provider" field.
func ProviderNotIn ¶
ProviderNotIn applies the NotIn predicate on the "provider" field.
func ProviderNotNil ¶
ProviderNotNil applies the NotNil predicate on the "provider" field.
func PublishedAt ¶
PublishedAt applies equality check predicate on the "published_at" field. It's identical to PublishedAtEQ.
func PublishedAtEQ ¶
PublishedAtEQ applies the EQ predicate on the "published_at" field.
func PublishedAtGT ¶
PublishedAtGT applies the GT predicate on the "published_at" field.
func PublishedAtGTE ¶
PublishedAtGTE applies the GTE predicate on the "published_at" field.
func PublishedAtIn ¶
PublishedAtIn applies the In predicate on the "published_at" field.
func PublishedAtIsNil ¶
PublishedAtIsNil applies the IsNil predicate on the "published_at" field.
func PublishedAtLT ¶
PublishedAtLT applies the LT predicate on the "published_at" field.
func PublishedAtLTE ¶
PublishedAtLTE applies the LTE predicate on the "published_at" field.
func PublishedAtNEQ ¶
PublishedAtNEQ applies the NEQ predicate on the "published_at" field.
func PublishedAtNotIn ¶
PublishedAtNotIn applies the NotIn predicate on the "published_at" field.
func PublishedAtNotNil ¶
PublishedAtNotNil applies the NotNil predicate on the "published_at" field.
func SizeNotNil ¶
SizeNotNil applies the NotNil predicate on the "size" field.
func TenantID ¶
TenantID applies equality check predicate on the "tenant_id" field. It's identical to TenantIDEQ.
func TenantIDContains ¶
TenantIDContains applies the Contains predicate on the "tenant_id" field.
func TenantIDContainsFold ¶
TenantIDContainsFold applies the ContainsFold predicate on the "tenant_id" field.
func TenantIDEQ ¶
TenantIDEQ applies the EQ predicate on the "tenant_id" field.
func TenantIDEqualFold ¶
TenantIDEqualFold applies the EqualFold predicate on the "tenant_id" field.
func TenantIDGT ¶
TenantIDGT applies the GT predicate on the "tenant_id" field.
func TenantIDGTE ¶
TenantIDGTE applies the GTE predicate on the "tenant_id" field.
func TenantIDHasPrefix ¶
TenantIDHasPrefix applies the HasPrefix predicate on the "tenant_id" field.
func TenantIDHasSuffix ¶
TenantIDHasSuffix applies the HasSuffix predicate on the "tenant_id" field.
func TenantIDIn ¶
TenantIDIn applies the In predicate on the "tenant_id" field.
func TenantIDLT ¶
TenantIDLT applies the LT predicate on the "tenant_id" field.
func TenantIDLTE ¶
TenantIDLTE applies the LTE predicate on the "tenant_id" field.
func TenantIDNEQ ¶
TenantIDNEQ applies the NEQ predicate on the "tenant_id" field.
func TenantIDNotIn ¶
TenantIDNotIn applies the NotIn predicate on the "tenant_id" field.
func URLContains ¶
URLContains applies the Contains predicate on the "url" field.
func URLContainsFold ¶
URLContainsFold applies the ContainsFold predicate on the "url" field.
func URLEqualFold ¶
URLEqualFold applies the EqualFold predicate on the "url" field.
func URLHasPrefix ¶
URLHasPrefix applies the HasPrefix predicate on the "url" field.
func URLHasSuffix ¶
URLHasSuffix applies the HasSuffix predicate on the "url" field.
func UpdatedAt ¶
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtIsNil ¶
UpdatedAtIsNil applies the IsNil predicate on the "updated_at" field.
func UpdatedAtLT ¶
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func UpdatedAtNotNil ¶
UpdatedAtNotNil applies the NotNil predicate on the "updated_at" field.
func UpdatedByID ¶
UpdatedByID applies equality check predicate on the "updated_by_id" field. It's identical to UpdatedByIDEQ.
func UpdatedByIDEQ ¶
UpdatedByIDEQ applies the EQ predicate on the "updated_by_id" field.
func UpdatedByIDGT ¶
UpdatedByIDGT applies the GT predicate on the "updated_by_id" field.
func UpdatedByIDGTE ¶
UpdatedByIDGTE applies the GTE predicate on the "updated_by_id" field.
func UpdatedByIDIn ¶
UpdatedByIDIn applies the In predicate on the "updated_by_id" field.
func UpdatedByIDIsNil ¶
UpdatedByIDIsNil applies the IsNil predicate on the "updated_by_id" field.
func UpdatedByIDLT ¶
UpdatedByIDLT applies the LT predicate on the "updated_by_id" field.
func UpdatedByIDLTE ¶
UpdatedByIDLTE applies the LTE predicate on the "updated_by_id" field.
func UpdatedByIDNEQ ¶
UpdatedByIDNEQ applies the NEQ predicate on the "updated_by_id" field.
func UpdatedByIDNotIn ¶
UpdatedByIDNotIn applies the NotIn predicate on the "updated_by_id" field.
func UpdatedByIDNotNil ¶
UpdatedByIDNotNil applies the NotNil predicate on the "updated_by_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func Width ¶
Width applies equality check predicate on the "width" field. It's identical to WidthEQ.
func WidthIsNil ¶
WidthIsNil applies the IsNil predicate on the "width" field.
func WidthNotIn ¶
WidthNotIn applies the NotIn predicate on the "width" field.
func WidthNotNil ¶
WidthNotNil applies the NotNil predicate on the "width" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the Media queries.
func ByAlternativeText ¶
func ByAlternativeText(opts ...sql.OrderTermOption) OrderOption
ByAlternativeText orders the results by the alternative_text field.
func ByArchivedAt ¶
func ByArchivedAt(opts ...sql.OrderTermOption) OrderOption
ByArchivedAt orders the results by the archived_at field.
func ByCaption ¶
func ByCaption(opts ...sql.OrderTermOption) OrderOption
ByCaption orders the results by the caption field.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByCreatedByID ¶
func ByCreatedByID(opts ...sql.OrderTermOption) OrderOption
ByCreatedByID orders the results by the created_by_id field.
func ByDeletedAt ¶
func ByDeletedAt(opts ...sql.OrderTermOption) OrderOption
ByDeletedAt orders the results by the deleted_at field.
func ByDeletedByID ¶
func ByDeletedByID(opts ...sql.OrderTermOption) OrderOption
ByDeletedByID orders the results by the deleted_by_id field.
func ByExt ¶
func ByExt(opts ...sql.OrderTermOption) OrderOption
ByExt orders the results by the ext field.
func ByFolderPath ¶
func ByFolderPath(opts ...sql.OrderTermOption) OrderOption
ByFolderPath orders the results by the folder_path field.
func ByFormats ¶
func ByFormats(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByFormats orders the results by formats terms.
func ByFormatsCount ¶
func ByFormatsCount(opts ...sql.OrderTermOption) OrderOption
ByFormatsCount orders the results by formats count.
func ByHash ¶
func ByHash(opts ...sql.OrderTermOption) OrderOption
ByHash orders the results by the hash field.
func ByHeight ¶
func ByHeight(opts ...sql.OrderTermOption) OrderOption
ByHeight orders the results by the height field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByIsURLSigned ¶
func ByIsURLSigned(opts ...sql.OrderTermOption) OrderOption
ByIsURLSigned orders the results by the is_url_signed field.
func ByLocale ¶
func ByLocale(opts ...sql.OrderTermOption) OrderOption
ByLocale orders the results by the locale field.
func ByMime ¶
func ByMime(opts ...sql.OrderTermOption) OrderOption
ByMime orders the results by the mime field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByPreviewURL ¶
func ByPreviewURL(opts ...sql.OrderTermOption) OrderOption
ByPreviewURL orders the results by the preview_url field.
func ByProvider ¶
func ByProvider(opts ...sql.OrderTermOption) OrderOption
ByProvider orders the results by the provider field.
func ByPublishedAt ¶
func ByPublishedAt(opts ...sql.OrderTermOption) OrderOption
ByPublishedAt orders the results by the published_at field.
func BySize ¶
func BySize(opts ...sql.OrderTermOption) OrderOption
BySize orders the results by the size field.
func ByTenantID ¶
func ByTenantID(opts ...sql.OrderTermOption) OrderOption
ByTenantID orders the results by the tenant_id field.
func ByURL ¶
func ByURL(opts ...sql.OrderTermOption) OrderOption
ByURL orders the results by the url field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
func ByUpdatedByID ¶
func ByUpdatedByID(opts ...sql.OrderTermOption) OrderOption
ByUpdatedByID orders the results by the updated_by_id field.
func ByWidth ¶
func ByWidth(opts ...sql.OrderTermOption) OrderOption
ByWidth orders the results by the width field.